#pragma once
#include <matrix/matrixModel.hpp>
#include <halp/layout.hpp>
/*
namespace spat
{
struct matrix::ui
{
  using enum halp::colors;
  using enum halp::layouts;

  halp_meta(name, "Main")
  halp_meta(layout, vbox)
  halp_meta(background, background_dark)

  halp::label title{"My First Processor"};
  halp::item<&ins::gain> gain;
};
}
*/
